A pre-fitted single-season occupancy model produced by flock using simulated data.

Details

This object is loaded lazily on first access.

The object is a brmsfit. Depending on how it was created, it may contain internal references to optional packages such as colorspace, lubridate, or terra.

If you encounter an error about missing namespaces when accessing this object, install the relevant packages.

Examples

if (FALSE) { # \dontrun{
library(flocker)
summary(example_flocker_model_single)
} # }